@@ -6,3 +6,7 @@ EXPOSE_MODEL_TO_ADMIN = getattr(settings, 'SITEPREFS_EXPOSE_MODEL_TO_ADMIN', Fal
 
 # Module name used by siteprefs.toolbox.autodiscover_siteprefs() to find preferences in application packages.
 PREFS_MODULE_NAME = getattr(settings, 'SITEPREFS_MODULE_NAME', 'settings')
+
+# List of commands called by manage.py where autodiscover is enabled
+MANAGE_SAFE_COMMANDS = getattr(settings, "SITEPREFS_MANAGE_SAFE_COMMANDS",
+                           ['runserver', 'runserver_plus', 'run_gunicorn', 'celeryd'])
